#! /bin/sh

# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 1993, 2014.  All Rights Reserved.
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp

# This script runs the vob_scrubber on each VOB whose storage directory is
# on this host.  Note that VOB scrubbing does not free disk space; it frees
# space within the VOB database files, which will be used for future updates.
# It should be run periodically (for example, once a week) to keep VOB
# databases from expanding unnecessarily.
#
# To customize VOB scrubbing or to prevent VOB scrubbing for a VOB, set up
# vob_scrubbber parameters in the VOB storage directory.  See the Clearcase
# documentation for more information on customizing vob_scrubber execution.

# Init
ATRIA_DIR=${CLEARCASEHOME:-${ATRIAHOME:-/opt/rational/clearcase}}

# Scrub all local VOBs; produce short report
$ATRIA_DIR/etc/vob_scrubber -lvobs
STATUS=$?

# If error, print a message
if [ $STATUS != 0 ]; then
    date

    # Find hostname
    HOSTNAME=`uname -n`

    # Find log file used for vob_scrubber output
    if [ -d /var/adm/rational/clearcase/log ]; then
        LOGDIR=/var/adm/rational/clearcase/log
    else
        echo "Can't find ClearCase log file directory."
        exit 1
    fi	
    LOG=$LOGDIR/vob_scrubber_log

    # Print message
    echo "ClearCase vob_scrubber on $HOSTNAME reported errors (exit status $STATUS)."
    echo "See $HOSTNAME:$LOG."
fi

exit $STATUS
